#!/usr/bin/env Rscript

################################################
#### Load required library
################################################

library(openxlsx)

################################################
#### Read arguments from CLI
################################################

args <- commandArgs(trailingOnly = T)

in_isa_study <- paste(args[1], ":plant_growth", sep="")
print(in_isa_study)
in_isa_assay <- paste(args[2], ":2EXT01_RNA:3ASY01_RNASeq", sep="")
print(in_isa_assay)
out_folder <- args[3]

################################################
#### Read metadata from isa excel workbooks
################################################

isa_study <- unlist(strsplit(in_isa_study, split = ":"))
isa_assay <- unlist(strsplit(in_isa_assay, split = ":"))

isa_sheets <- list()
for (i in 2:length(isa_study))
{
  isa_sheets[[length(isa_sheets) + 1]] <- readWorkbook(isa_study[1], isa_study[i], startRow = 1)
}

for (i in 2:length(isa_assay))
{
  isa_sheets[[length(isa_sheets) + 1]] <- readWorkbook(isa_assay[1], isa_assay[i], startRow = 1)
}

################################################
#### Merge consecutively right (Source.Name) to left (Sample.Name)
################################################

isa_merged <- isa_sheets[[1]]

for (j in 2:length(isa_sheets))
# for(j in 2)
{
  isa_merged <- merge(isa_merged,
    isa_sheets[[j]],
    by.x = "Sample.Name",
    by.y = "Source.Name",
  )

  # Rename duplicated Sample.Name column

  colnames(isa_merged)[which(colnames(isa_merged) == "Sample.Name")] <- paste("Sample.Name", j, sep = ".")
  colnames(isa_merged)[which(colnames(isa_merged) == "Sample.Name.y")] <- "Sample.Name"
}


## remove empty columns
isa_merged <- isa_merged[, !apply(isa_merged, 2, function(x) {
  sum(is.na(x)) == nrow(isa_merged)
})]


################################################
#### If it does not exist, create out dir
################################################

dir.create(out_folder, recursive = T, showWarnings = F)

################################################
#### Write table to file
################################################

write.table(isa_merged, file = paste(out_folder, "merged_isa.tsv", sep = "/"), sep = "\t")
